#!/bin/sh
# the next line restarts using tclsh \
exec expect -- "$0" "$@"
# --------------------------
# -------- OVERVIEW --------
# --------------------------
#
# This script forms the basis of a Data Input Method for Cacti.
# The purpose is to query a Cisco Wireless Access Point for all
# connected clients' RSSI (received signal strength indication)
# These values are indexed against client MAC addresses and are
# not directly graphable. So we take an average of all connected
# clients' RSSI values as a general indication of AP performance.
# May help with spotting placement issues in your environment.
#
# ---------------------------
# -------- CHANGELOG --------
# ---------------------------
#
# 20080724 (BC)
#       Initial version
#
# ----------------------------------------
# -------- CAVEATS / BUGS / TO DO --------
# ----------------------------------------
#
# 20080724 (BC)
#
# -----------------------------
# -------- GLOBAL VARS --------
# -----------------------------

# Default vars
set oid .1.3.6.1.4.1.9.9.273.1.3.1.1.3
#set comstr 
#set ver 2c
#set host 10.10.4.58

# ------------------------------
# -------- PROCESS ARGS --------
# ------------------------------

if {[llength $argv] != 3} {
        puts stderr "Error: You didn't provide three arguments to the script"
        #puts 0
        exit 1
}

set host [lindex $argv 0]
set comstr [lindex $argv 1]
set ver [lindex $argv 2] ; if { $ver eq 2 } { set ver 2c }

#puts "snmpwalk -v $ver -c $comstr $host $oid" ; exit

# ------------------------------
# -------- START SCRIPT --------
# ------------------------------

if { [catch { set walk_result [exec snmpwalk -v $ver -c $comstr $host $oid] } result] } {
	puts stderr "Error: There was some problem running snmpwalk:\n\t$result"
	#puts 0
	exit 1	

} else {
	# Make a list of every value
	set rssis ""
	foreach line [split $walk_result "\n"] {
		if { [regexp { = INTEGER: -([0-9]{1,3})$} $line xxx rssi] } {
			#puts "rssi is $rssi"
			lappend rssis $rssi
		} else {
		        puts stderr "Error: No valid result received from snmpwalk"
		        #puts 0
		        exit 1
		}
	}

	# Average the values
	#puts $rssis
	set numerator 0
	foreach num $rssis { set numerator [expr $numerator + $num] }
	set denominator [llength $rssis]
	set avg_rssi [expr $numerator / $denominator]
	#puts "avg_rssi is $avg_rssi"
	puts $avg_rssi
	return $avg_rssi
}

